@@ -1,5 +1,5 @@
 package CPAN::ReleaseHistory::ReleaseIterator;
-$CPAN::ReleaseHistory::ReleaseIterator::VERSION = '0.11';
+$CPAN::ReleaseHistory::ReleaseIterator::VERSION = '0.12';
 use Moo;
 use CPAN::ReleaseHistory;
 use CPAN::ReleaseHistory::Release;
@@ -65,3 +65,27 @@ sub next_release
 
 1;
 
+=head1 NAME
+
+CPAN::ReleaseHistory::ReleaseIterator - Release iterator for CPAN::ReleaseHistory.
+
+=head1 DESCRIPTION
+
+B<FOR INTERNAL USE ONLY>
+
+=head1 REPOSITORY
+
+L<https://github.com/neilbowers/CPAN-ReleaseHistory>
+
+=head1 AUTHOR
+
+Neil Bowers E<lt>neilb@cpan.orgE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Neil Bowers <neilb@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
